@@ -27,12 +27,11 @@
 #include <stdlib.h>
 
 void
-G_GNUC_INTERNAL
 _glibtop_bsd_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
 				      const char *path);
 
-void G_GNUC_INTERNAL
+void
 _glibtop_bsd_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
 				      const char *path)
@@ -54,7 +53,9 @@ _glibtop_bsd_get_fsusage_read_write(glibtop *server,
 		return;
 	}
 
+#if !defined(__OpenBSD__)
 	buf->read = sfs.f_syncreads + sfs.f_asyncreads;
+#endif
 	buf->write = sfs.f_syncwrites + sfs.f_asyncwrites;
 	buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
 }
