@@ -31,7 +31,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	const glibtop_init_func_t *init_fkt;
+	const _glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
@@ -63,9 +63,11 @@ glibtop_open_p (glibtop *server, const char *program_name,
 	server->machine.euid = geteuid ();
 	server->machine.gid = getgid ();
 	server->machine.egid = getegid ();
-
+#if defined(__FreeBSD_kernel__)
+	server->os_version_code = __FreeBSD_kernel_version;
+#else
 	server->os_version_code = __FreeBSD_version;
-
+#endif
 	/* Setup machine-specific data */
 	server->machine.kd = kvm_open (NULL, NULL, NULL, O_RDONLY, "kvm_open");
 
